@@ -1,5 +1,4 @@
-/* kpackage.h
-**
+/*
 ** Copyright (C) 1999,2000 Toivo Pedaste <toivo@ucs.uwa.edu.au>
 **
 ** This is the main widget for kpackage
@@ -20,8 +19,8 @@
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program in a file called COPYING; if not, write to
-** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-** MA 02111-1307, USA.
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
 */
 
 /*
@@ -57,7 +56,7 @@ class KRecentFilesAction;
 class KAction;
 class kpRun;
 
-#define kpinterfaceN 6
+#define kpinterfaceN 7
 
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
@@ -67,7 +66,7 @@ class KPACKAGE : public QWidget
 
   ///////////// METHODS ------------------------------------------------------
 public:
-  KPACKAGE(KConfig *_config, QWidget *parent=0);
+  KPACKAGE(KConfig *_config, QWidget *parent);
   // Constructor
 
   ~KPACKAGE();
@@ -94,7 +93,10 @@ public:
   pkgInterface *pkType(const QString &fname);
   // find type of package
 
-  void openNetFiles(QStringList urls, bool install=TRUE);
+  int typeIndex(pkgInterface *);
+  // convert interface pointer to index
+  
+  void openNetFiles(const QStringList &urls, bool install=TRUE);
   void openNetFile(const KURL & url, bool install=TRUE);
   // open a file given a URL
 
@@ -165,6 +167,9 @@ public slots:
   void fileQuit();
   // This is called when File->Quit is selected from the menu
 
+  void cleanUp();
+  // Cleanup for Exit
+
   void reload();
   // reload file package infomation
 
@@ -185,6 +190,9 @@ public:
   KURL save_url;
   // save the URL entered
 
+  FindF *findialog;
+  // find file dialog
+
 private:
   int mode;
   // Widget mode
@@ -206,8 +214,6 @@ private:
   Search *srchdialog;
   // find package dialog
 
-  FindF *findialog;
-  // find file dialog
 };
 
 //////////////////////////////////////////////////////////////////////////////
@@ -294,8 +300,6 @@ public slots:
   void setOptions();
   // set options
 
-  void setKeys();
-
   void saveSettings();
   // save config
 
@@ -311,7 +315,7 @@ private slots:
   void slotNewToolbarConfig();
 
 protected:
-  void closeEvent ( QCloseEvent *e);
+  bool queryClose ();
 };
 
 //////////////////////////////////////////////////////////////////////////////
@@ -326,7 +330,7 @@ extern QString hostName;
 
 extern pkgInterface *kpinterface[];
 
-void KpMsg(QString lab, QString msg, bool stop);
-void KpMsgE(QString msg, bool stop = FALSE);
+void KpMsg(const QString &lab, const QString &msg, bool stop);
+void KpMsgE(const QString &msg, bool stop = FALSE);
 #endif
 
