@@ -1,5 +1,4 @@
-/* managementWidget.h
-**
+/*
 ** Copyright (C) 1999,2000 Toivo Pedaste <toivo@ucs.uwa.edu.au>
 **
 // Author: Damyan Pepper
@@ -26,8 +25,8 @@
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program in a file called COPYING; if not, write to
-** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-** MA 02111-1307, USA.
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
 */
 
 /*
@@ -50,11 +49,13 @@
 #include <qstring.h>
 #include <qlayout.h>
 #include <qtabwidget.h>
-
+#include <qlabel.h>
+#include <qhbox.h>
 
 // KDE headers
 #include <kaction.h>
 #include <klistview.h>
+#include <klistviewsearchline.h>
 
 // ksetup headers
 #include "packageInfo.h"
@@ -63,6 +64,27 @@
 class packageDisplayWidget;
 class packageInfo;
 class QSplitter;
+class KActionCollection;
+class KToolBar;
+class managementWidget;
+
+class KpListViewSearchLine : public KListViewSearchLine
+{
+  Q_OBJECT
+
+public:
+
+  KpListViewSearchLine(QWidget *parent, KpTreeList *listView);
+
+  ~KpListViewSearchLine();
+
+  
+  void updateSearch(const QString &s = QString::null);
+
+private:
+  KpTreeList *list;
+};
+
 
 class managementWidget : public QFrame
 {
@@ -70,61 +92,24 @@ class managementWidget : public QFrame
 
   ///////////// METHODS ------------------------------------------------------
 public:
-  managementWidget(QWidget *parent=0);
+  managementWidget(QWidget *parent);
   // Constructor
 
   ~managementWidget();
   // Destructor
 
-  KPLVItem *search(QString str, QString head,
-			KPLVItem  *start = 0);
-  KPLVItem *search(QString str, bool subStr, bool wrap, bool start);
-  // search for a package in tree
-
-  KPLVItem *changePack(KPLVItem *searchResult, bool push = true);
-  // Change to other package
-
-  KPLVItem *updatePackage(packageInfo *pki, bool install);
+  KpTreeListItem *updatePackage(packageInfo *pki, bool install);
   // update package in treelist
 
   void readPSeparator();
   void writePSeparator();
   // config: position of panel seperator
 
-  void readTreeType();
-  void writeTreeType();
-  // config: Tree display type
-
-  void expandTree(KPQListView *list);
-  // expand package tree
-
-  void expandTree(KPLVItem *item);
-  // expand package sub-tree
-
-  void collapseTree(KPQListView *list);
-  // semi-collapse package tree
-
-  void collapseTree(KPLVItem *item);
-  // semi-collapse package sub-tree
-
-  void writeTreePos();
-  void readTreePos();
-  // save and restore column positions
-
-  void findMarked(KPLVItem *item);
-  // generate list of marked tree items
-  void clearMarked(KPLVItem *item);
-  // unmark marked tree items
-
-  // mark all packages in the selected view
-  void markAll(KPLVItem *item) ;
-
-  void sweep() ;
-  // sweep package tree adjusting visibility
-
-  void doChangePackage(packageInfo *p);
+ void doChangePackage(packageInfo *p);
   // emit change package
 
+  KpTreeListItem *search(QString str, bool subStr, bool wrap,
+		    bool start=FALSE);
 protected:
   void resizeEvent(QResizeEvent *re);
   // This is called when the widget is resized
@@ -140,13 +125,7 @@ private:
   // This arranges the widgets in the window (should be called after a
   // resize event)
 
-  int  sweepChild(KPLVItem *it);
-  // recursive routine for sweep
-
-  void countMarked(KPLVItem *);
-  // Count marked packages that can be installed/uninstalled
-
-  void setupMultButton();
+  void setupMultButton(int &cntInstall, int &cntUnInstall);
   // Setup mult install/uninstall button appropriately
 
 
@@ -175,15 +154,6 @@ private:
   void installMultClicked();
   // This is called when the install button has been clicked with multiple packages
 
-  void stackRemove(KPLVItem *pack);
-  // Remove entry from package stack
-
-  void next();
-  // Package stack forward
-
-  void previous();
-  // Package stack back
-
   void setInstallAction(KAction *a) { install_action = a; }
   void setUninstallAction(KAction *a) { uninstall_action = a; }
 
@@ -220,34 +190,14 @@ private:
   QSplitter *vPan;
   // veritcal panner between panels
 
-  bool searchChild(KPLVItem *it);
-  // recurse thru the display tree looking for 'str'
+  KToolBar *searchToolBar;
 
-  KPLVItem *searchCitem;
-  bool searchSkip, searchSubstr;
-  QString searchStr;
-  KPLVItem  *searchResult;
-  // globals used by searchChild for start from current position,
-  // skip to current item before search flag, substring search flag,
-  // search string, result item (if found)
-
-  // flag skipping in searchChild
-
-  QPtrList<KPLVItem> selList;
+  QPtrList<KpTreeListItem> selList;
   // list for selected packages
 
-  bool notPress;
-  // flag to packageHighlighted
-
   QString tType[4];
   // identifiers for tree display
 
-  int treeType;
-  // type of tree display
-
-  int cntInstall, cntUnInstall;
-  // marked packages that can be installed/uninstalled
-
 public:
   QPtrList<packageInfo> *allPackages;
   // The list of packages
@@ -261,11 +211,11 @@ public:
   QDict<packageInfo> *dirInfoPackages;
   // maps Info package name to package
 
-  KPQListView *treeList;
+  KpTreeList *treeList;
   // This is the tree list where all the packages / groups are displayed
 
-  QPtrList<KPLVItem> stack;
-  // Stack of jumped to pacckages
+  KpListViewSearchLine *searchLine;
+  // Widget for search treeList
 
   KAction *install_action;
   KAction *uninstall_action;
