@@ -1,6 +1,7 @@
 /*
  *  Copyright (c) 1998 Denis Perchine <dyp@perchine.com>
- *  Maintained by Adriaan de Groot <groot@kde.org>
+ *  Copyright (c) 2004 Szombathelyi György <gyurco@freemail.hu>
+ *  Former maintainer: Adriaan de Groot <groot@kde.org>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public
@@ -13,8 +14,8 @@
  *
  *  You should have received a copy of the GNU Library General Public License
  *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- *  Boston, MA 02111-1307, USA.
+ *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ *  Boston, MA 02110-1301, USA.
  **/
 
 #ifndef _KU_ADDUSER_H_
@@ -26,11 +27,8 @@
 class addUser: public propdlg {
   Q_OBJECT
 public:
-#ifdef _KU_QUOTA
-  addUser(KUser *AUser, Quota *AQuota, QWidget *parent = 0, const char *name = 0, int isprep = false);
-#else
-  addUser(KUser *AUser, QWidget *parent = 0, const char *name = 0, int isprep = false);
-#endif
+  addUser(KU::KUser *AUser, bool useprivategroup, 
+    QWidget *parent = 0, const char *name = 0 );
 
   void setCreateHomeDir(bool b)
      { createhome->setChecked(b); }
@@ -38,13 +36,6 @@ public:
   void setCopySkel(bool b)
      { copyskel->setChecked(b); }
 
-  void setUsePrivateGroup(bool b)
-     { usePrivateGroup->setChecked(b); }
-
-  bool getUsePrivateGroup()
-     { return usePrivateGroup->isChecked(); }
-
-
 protected slots:
   virtual void slotOk();
 protected:
@@ -53,7 +44,6 @@ protected:
 
   QCheckBox *createhome;
   QCheckBox *copyskel;
-  QCheckBox *usePrivateGroup;
 };
 
 #endif // _KU_ADDUSER_H
