@@ -14,12 +14,12 @@
  *
  *  You should have received a copy of the GNU Library General Public License
  *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- *  Boston, MA 02111-1307, USA.
+ *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ *  Boston, MA 02110-1301, USA.
  **/
 
-#ifndef _KU_PWDDLG
-#define _KU_PWDDLG
+#ifndef _KU_PWDDLG_H_
+#define _KU_PWDDLG_H_
 
 #include <qstring.h>
 #include <klineedit.h>
@@ -41,4 +41,4 @@ private:
   KLineEdit   *lepw2;
 };
 
-#endif // _KU_PWDDLG
+#endif // _KU_PWDDLG_H_
